# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto',
  package='yandex.cloud.kms.v1.asymmetricencryption',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nSyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\x18\x41symmetricDecryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nciphertext\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\">\n\x19\x41symmetricDecryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\xd7\x03\n!AsymmetricEncryptionCryptoService\x12\xd0\x01\n\x07\x44\x65\x63rypt\x12\x42.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\x01*\x12\xde\x01\n\x0cGetPublicKey\x12G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest\x1aH.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKeyBk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ASYMMETRICDECRYPTREQUEST = _descriptor.Descriptor(
  name='AsymmetricDecryptRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=283,
)


_ASYMMETRICDECRYPTRESPONSE = _descriptor.Descriptor(
  name='AsymmetricDecryptResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=347,
)


_ASYMMETRICGETPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=410,
)


_ASYMMETRICGETPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=480,
)

DESCRIPTOR.message_types_by_name['AsymmetricDecryptRequest'] = _ASYMMETRICDECRYPTREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricDecryptResponse'] = _ASYMMETRICDECRYPTRESPONSE
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyRequest'] = _ASYMMETRICGETPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyResponse'] = _ASYMMETRICGETPUBLICKEYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AsymmetricDecryptRequest = _reflection.GeneratedProtocolMessageType('AsymmetricDecryptRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICDECRYPTREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest)
  })
_sym_db.RegisterMessage(AsymmetricDecryptRequest)

AsymmetricDecryptResponse = _reflection.GeneratedProtocolMessageType('AsymmetricDecryptResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICDECRYPTRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse)
  })
_sym_db.RegisterMessage(AsymmetricDecryptResponse)

AsymmetricGetPublicKeyRequest = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyRequest)

AsymmetricGetPublicKeyResponse = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyResponse)


DESCRIPTOR._options = None
_ASYMMETRICDECRYPTREQUEST.fields_by_name['key_id']._options = None
_ASYMMETRICDECRYPTREQUEST.fields_by_name['ciphertext']._options = None
_ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None

_ASYMMETRICENCRYPTIONCRYPTOSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricEncryptionCryptoService',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=483,
  serialized_end=954,
  methods=[
  _descriptor.MethodDescriptor(
    name='Decrypt',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService.Decrypt',
    index=0,
    containing_service=None,
    input_type=_ASYMMETRICDECRYPTREQUEST,
    output_type=_ASYMMETRICDECRYPTRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicKey',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService.GetPublicKey',
    index=1,
    containing_service=None,
    input_type=_ASYMMETRICGETPUBLICKEYREQUEST,
    output_type=_ASYMMETRICGETPUBLICKEYRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKey',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICENCRYPTIONCRYPTOSERVICE)

DESCRIPTOR.services_by_name['AsymmetricEncryptionCryptoService'] = _ASYMMETRICENCRYPTIONCRYPTOSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto',
  package='yandex.cloud.kms.v1.asymmetricsignature',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x15\x41symmetricSignRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x07message\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\";\n\x16\x41symmetricSignResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"W\n\x19\x41symmetricSignHashRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x04hash\x18\x02 \x01(\x0c\x42\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=4096\"?\n\x1a\x41symmetricSignHashResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\x98\x05\n AsymmetricSignatureCryptoService\x12\xc1\x01\n\x04Sign\x12>.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest\x1a?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\x01*\x12\xd1\x01\n\x08SignHash\x12\x42.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\x01*\x12\xdb\x01\n\x0cGetPublicKey\x12\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest\x1aG.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/kms/v1/asymmetricSignatureKeys/{key_id}/publicKeyBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ASYMMETRICSIGNREQUEST = _descriptor.Descriptor(
  name='AsymmetricSignRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=274,
)


_ASYMMETRICSIGNRESPONSE = _descriptor.Descriptor(
  name='AsymmetricSignResponse',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=335,
)


_ASYMMETRICSIGNHASHREQUEST = _descriptor.Descriptor(
  name='AsymmetricSignHashRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=4096', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=424,
)


_ASYMMETRICSIGNHASHRESPONSE = _descriptor.Descriptor(
  name='AsymmetricSignHashResponse',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=489,
)


_ASYMMETRICGETPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=552,
)


_ASYMMETRICGETPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='AsymmetricGetPublicKeyResponse',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=622,
)

DESCRIPTOR.message_types_by_name['AsymmetricSignRequest'] = _ASYMMETRICSIGNREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricSignResponse'] = _ASYMMETRICSIGNRESPONSE
DESCRIPTOR.message_types_by_name['AsymmetricSignHashRequest'] = _ASYMMETRICSIGNHASHREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricSignHashResponse'] = _ASYMMETRICSIGNHASHRESPONSE
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyRequest'] = _ASYMMETRICGETPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['AsymmetricGetPublicKeyResponse'] = _ASYMMETRICGETPUBLICKEYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AsymmetricSignRequest = _reflection.GeneratedProtocolMessageType('AsymmetricSignRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICSIGNREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest)
  })
_sym_db.RegisterMessage(AsymmetricSignRequest)

AsymmetricSignResponse = _reflection.GeneratedProtocolMessageType('AsymmetricSignResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICSIGNRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse)
  })
_sym_db.RegisterMessage(AsymmetricSignResponse)

AsymmetricSignHashRequest = _reflection.GeneratedProtocolMessageType('AsymmetricSignHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICSIGNHASHREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest)
  })
_sym_db.RegisterMessage(AsymmetricSignHashRequest)

AsymmetricSignHashResponse = _reflection.GeneratedProtocolMessageType('AsymmetricSignHashResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICSIGNHASHRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse)
  })
_sym_db.RegisterMessage(AsymmetricSignHashResponse)

AsymmetricGetPublicKeyRequest = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyRequest)

AsymmetricGetPublicKeyResponse = _reflection.GeneratedProtocolMessageType('AsymmetricGetPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICGETPUBLICKEYRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse)
  })
_sym_db.RegisterMessage(AsymmetricGetPublicKeyResponse)


DESCRIPTOR._options = None
_ASYMMETRICSIGNREQUEST.fields_by_name['key_id']._options = None
_ASYMMETRICSIGNREQUEST.fields_by_name['message']._options = None
_ASYMMETRICSIGNHASHREQUEST.fields_by_name['key_id']._options = None
_ASYMMETRICSIGNHASHREQUEST.fields_by_name['hash']._options = None
_ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None

_ASYMMETRICSIGNATURECRYPTOSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricSignatureCryptoService',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureCryptoService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=625,
  serialized_end=1289,
  methods=[
  _descriptor.MethodDescriptor(
    name='Sign',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureCryptoService.Sign',
    index=0,
    containing_service=None,
    input_type=_ASYMMETRICSIGNREQUEST,
    output_type=_ASYMMETRICSIGNRESPONSE,
    serialized_options=b'\202\323\344\223\0022\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignHash',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureCryptoService.SignHash',
    index=1,
    containing_service=None,
    input_type=_ASYMMETRICSIGNHASHREQUEST,
    output_type=_ASYMMETRICSIGNHASHRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicKey',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureCryptoService.GetPublicKey',
    index=2,
    containing_service=None,
    input_type=_ASYMMETRICGETPUBLICKEYREQUEST,
    output_type=_ASYMMETRICGETPUBLICKEYRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/kms/v1/asymmetricSignatureKeys/{key_id}/publicKey',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICSIGNATURECRYPTOSERVICE)

DESCRIPTOR.services_by_name['AsymmetricSignatureCryptoService'] = _ASYMMETRICSIGNATURECRYPTOSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1.asymmetricsignature import asymmetric_signature_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key_service.proto',
  package='yandex.cloud.kms.v1.asymmetricsignature',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nNyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key_service.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x46yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto\"\xdc\x03\n#CreateAsymmetricSignatureKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\xa9\x01\n\x06labels\x18\x04 \x03(\x0b\x32X.yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x62\n\x13signature_algorithm\x18\x05 \x01(\x0e\x32\x45.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n$CreateAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"@\n GetAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x83\x01\n\"ListAsymmetricSignatureKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8d\x01\n#ListAsymmetricSignatureKeysResponse\x12M\n\x04keys\x18\x01 \x03(\x0b\x32?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x04\n#UpdateAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12V\n\x06status\x18\x05 \x01(\x0e\x32\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status\x12\xa9\x01\n\x06labels\x18\x06 \x03(\x0b\x32X.yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n$UpdateAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"C\n#DeleteAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n$DeleteAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x89\x01\n+ListAsymmetricSignatureKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"~\n,ListAsymmetricSignatureKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\x10\n\x1d\x41symmetricSignatureKeyService\x12\xe7\x01\n\x06\x43reate\x12L.yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"l\x82\xd3\xe4\x93\x02$\"\x1f/kms/v1/asymmetricSignatureKeys:\x01*\xb2\xd2*>\n$CreateAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x12\xc3\x01\n\x03Get\x12I.yandex.cloud.kms.v1.asymmetricsignature.GetAsymmetricSignatureKeyRequest\x1a?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey\"0\x82\xd3\xe4\x93\x02*\x12(/kms/v1/asymmetricSignatureKeys/{key_id}\x12\xca\x01\n\x04List\x12K.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest\x1aL.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/kms/v1/asymmetricSignatureKeys\x12\xf0\x01\n\x06Update\x12L.yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"u\x82\xd3\xe4\x93\x02-2(/kms/v1/asymmetricSignatureKeys/{key_id}:\x01*\xb2\xd2*>\n$UpdateAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x12\xed\x01\n\x06\x44\x65lete\x12L.yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"r\x82\xd3\xe4\x93\x02**(/kms/v1/asymmetricSignatureKeys/{key_id}\xb2\xd2*>\n$DeleteAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x12\xfa\x01\n\x0eListOperations\x12T.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest\x1aU.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/kms/v1/asymmetricSignatureKeys/{key_id}/operations\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/kms/v1/asymmetricSignatureKeys/{resource_id}:listAccessBindings\x12\xef\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\x82\xd3\xe4\x93\x02\x44\"?/kms/v1/asymmetricSignatureKeys/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xfb\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\x82\xd3\xe4\x93\x02G\"B/kms/v1/asymmetricSignatureKeys/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2.DESCRIPTOR,])




_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=875,
)

_CREATEASYMMETRICSIGNATUREKEYREQUEST = _descriptor.Descriptor(
  name='CreateAsymmetricSignatureKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_algorithm', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.signature_algorithm', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.deletion_protection', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=875,
)


_CREATEASYMMETRICSIGNATUREKEYMETADATA = _descriptor.Descriptor(
  name='CreateAsymmetricSignatureKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=931,
)


_GETASYMMETRICSIGNATUREKEYREQUEST = _descriptor.Descriptor(
  name='GetAsymmetricSignatureKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.GetAsymmetricSignatureKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.GetAsymmetricSignatureKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=997,
)


_LISTASYMMETRICSIGNATUREKEYSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricSignatureKeysRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1131,
)


_LISTASYMMETRICSIGNATUREKEYSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricSignatureKeysResponse',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1275,
)


_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=875,
)

_UPDATEASYMMETRICSIGNATUREKEYREQUEST = _descriptor.Descriptor(
  name='UpdateAsymmetricSignatureKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.deletion_protection', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1278,
  serialized_end=1794,
)


_UPDATEASYMMETRICSIGNATUREKEYMETADATA = _descriptor.Descriptor(
  name='UpdateAsymmetricSignatureKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1796,
  serialized_end=1850,
)


_DELETEASYMMETRICSIGNATUREKEYREQUEST = _descriptor.Descriptor(
  name='DeleteAsymmetricSignatureKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1919,
)


_DELETEASYMMETRICSIGNATUREKEYMETADATA = _descriptor.Descriptor(
  name='DeleteAsymmetricSignatureKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=1975,
)


_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricSignatureKeyOperationsRequest',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1978,
  serialized_end=2115,
)


_LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricSignatureKeyOperationsResponse',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2243,
)

_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY.containing_type = _CREATEASYMMETRICSIGNATUREKEYREQUEST
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels'].message_type = _CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['signature_algorithm'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2._ASYMMETRICSIGNATUREALGORITHM
_LISTASYMMETRICSIGNATUREKEYSRESPONSE.fields_by_name['keys'].message_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2._ASYMMETRICSIGNATUREKEY
_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY.containing_type = _UPDATEASYMMETRICSIGNATUREKEYREQUEST
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2._ASYMMETRICSIGNATUREKEY_STATUS
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels'].message_type = _UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY
_LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['CreateAsymmetricSignatureKeyRequest'] = _CREATEASYMMETRICSIGNATUREKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateAsymmetricSignatureKeyMetadata'] = _CREATEASYMMETRICSIGNATUREKEYMETADATA
DESCRIPTOR.message_types_by_name['GetAsymmetricSignatureKeyRequest'] = _GETASYMMETRICSIGNATUREKEYREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricSignatureKeysRequest'] = _LISTASYMMETRICSIGNATUREKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricSignatureKeysResponse'] = _LISTASYMMETRICSIGNATUREKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAsymmetricSignatureKeyRequest'] = _UPDATEASYMMETRICSIGNATUREKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateAsymmetricSignatureKeyMetadata'] = _UPDATEASYMMETRICSIGNATUREKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteAsymmetricSignatureKeyRequest'] = _DELETEASYMMETRICSIGNATUREKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAsymmetricSignatureKeyMetadata'] = _DELETEASYMMETRICSIGNATUREKEYMETADATA
DESCRIPTOR.message_types_by_name['ListAsymmetricSignatureKeyOperationsRequest'] = _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricSignatureKeyOperationsResponse'] = _LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAsymmetricSignatureKeyRequest = _reflection.GeneratedProtocolMessageType('CreateAsymmetricSignatureKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEASYMMETRICSIGNATUREKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest)
  })
_sym_db.RegisterMessage(CreateAsymmetricSignatureKeyRequest)
_sym_db.RegisterMessage(CreateAsymmetricSignatureKeyRequest.LabelsEntry)

CreateAsymmetricSignatureKeyMetadata = _reflection.GeneratedProtocolMessageType('CreateAsymmetricSignatureKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEASYMMETRICSIGNATUREKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyMetadata)
  })
_sym_db.RegisterMessage(CreateAsymmetricSignatureKeyMetadata)

GetAsymmetricSignatureKeyRequest = _reflection.GeneratedProtocolMessageType('GetAsymmetricSignatureKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETASYMMETRICSIGNATUREKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.GetAsymmetricSignatureKeyRequest)
  })
_sym_db.RegisterMessage(GetAsymmetricSignatureKeyRequest)

ListAsymmetricSignatureKeysRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricSignatureKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICSIGNATUREKEYSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricSignatureKeysRequest)

ListAsymmetricSignatureKeysResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricSignatureKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICSIGNATUREKEYSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricSignatureKeysResponse)

UpdateAsymmetricSignatureKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricSignatureKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEASYMMETRICSIGNATUREKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest)
  })
_sym_db.RegisterMessage(UpdateAsymmetricSignatureKeyRequest)
_sym_db.RegisterMessage(UpdateAsymmetricSignatureKeyRequest.LabelsEntry)

UpdateAsymmetricSignatureKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricSignatureKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEASYMMETRICSIGNATUREKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateAsymmetricSignatureKeyMetadata)

DeleteAsymmetricSignatureKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricSignatureKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICSIGNATUREKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyRequest)
  })
_sym_db.RegisterMessage(DeleteAsymmetricSignatureKeyRequest)

DeleteAsymmetricSignatureKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricSignatureKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICSIGNATUREKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteAsymmetricSignatureKeyMetadata)

ListAsymmetricSignatureKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricSignatureKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricSignatureKeyOperationsRequest)

ListAsymmetricSignatureKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricSignatureKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricSignatureKeyOperationsResponse)


DESCRIPTOR._options = None
_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._options = None
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['folder_id']._options = None
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._options = None
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._options = None
_CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._options = None
_GETASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['folder_id']._options = None
_LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_token']._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['update_mask']._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._options = None
_UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._options = None
_DELETEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_ASYMMETRICSIGNATUREKEYSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricSignatureKeyService',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2246,
  serialized_end=4340,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEASYMMETRICSIGNATUREKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/kms/v1/asymmetricSignatureKeys:\001*\262\322*>\n$CreateAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.Get',
    index=1,
    containing_service=None,
    input_type=_GETASYMMETRICSIGNATUREKEYREQUEST,
    output_type=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2._ASYMMETRICSIGNATUREKEY,
    serialized_options=b'\202\323\344\223\002*\022(/kms/v1/asymmetricSignatureKeys/{key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.List',
    index=2,
    containing_service=None,
    input_type=_LISTASYMMETRICSIGNATUREKEYSREQUEST,
    output_type=_LISTASYMMETRICSIGNATUREKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/kms/v1/asymmetricSignatureKeys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEASYMMETRICSIGNATUREKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-2(/kms/v1/asymmetricSignatureKeys/{key_id}:\001*\262\322*>\n$UpdateAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEASYMMETRICSIGNATUREKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002**(/kms/v1/asymmetricSignatureKeys/{key_id}\262\322*>\n$DeleteAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST,
    output_type=_LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/kms/v1/asymmetricSignatureKeys/{key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/kms/v1/asymmetricSignatureKeys/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002D\"?/kms/v1/asymmetricSignatureKeys/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G\"B/kms/v1/asymmetricSignatureKeys/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICSIGNATUREKEYSERVICE)

DESCRIPTOR.services_by_name['AsymmetricSignatureKeyService'] = _ASYMMETRICSIGNATUREKEYSERVICE

# @@protoc_insertion_point(module_scope)
